==> haskell-binary-instances-1.0.4-116-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-instances
version:              1.0.4
visibility:           public
id:                   binary-instances-1.0.4-8yB7BacABXH6tvHHFnb53S
key:                  binary-instances-1.0.4-8yB7BacABXH6tvHHFnb53S
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/haskellari/binary-instances#readme
synopsis:             Orphan instances for binary
description:
    `binary-instances` defines orphan instances for types in some popular packages.

category:             Web
abi:                  0441ba8fe220b76bd583f3d0217ae42f
exposed:              True
exposed-modules:
    Data.Binary.Instances Data.Binary.Instances.Aeson
    Data.Binary.Instances.CaseInsensitive
    Data.Binary.Instances.Hashable Data.Binary.Instances.Primitive
    Data.Binary.Instances.Scientific Data.Binary.Instances.Tagged
    Data.Binary.Instances.Text Data.Binary.Instances.Time
    Data.Binary.Instances.UnorderedContainers
    Data.Binary.Instances.Vector

import-dirs:          /usr/lib/ghc-9.4.8/site-local/binary-instances-1.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/binary-instances-1.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/binary-instances-1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-instances
hs-libraries:         HSbinary-instances-1.0.4-8yB7BacABXH6tvHHFnb53S
depends:
    aeson-2.1.2.1-4ODQ1UQyjV4HqW8vjPOsEA base-4.17.2.1 binary-0.8.9.1
    binary-orphans-1.0.5-DWEHGmbwBuaHpvQas7oxSu
    case-insensitive-1.2.1.0-6fVgEt7vrFc1sDHTeWeWXd
    hashable-1.4.4.0-BPBogvz51gTFqjBeDWtSVb
    primitive-0.9.1.0-ICFc9Oc8RCqLS4oNEzcX43
    scientific-0.3.8.0-KN45uED49ez8IbcjYjrLBN
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2
    text-binary-0.2.1.1-2Sbl9JTNRDTGn32vfvCeKg
    time-compat-1.9.7-EkVz2DSU8CKL4BsrcKf3SM
    unordered-containers-0.2.20-7dvM9aaOf5JATet72j0BPX
    vector-0.13.2.0-JDMr93x2QgFDQPvksTJZzq
    vector-binary-instances-0.2.5.2-Aqp7owI7dxp7xsb9WnAv9n

haddock-interfaces:
    /usr/share/doc/haskell-binary-instances/html/binary-instances.haddock

haddock-html:         /usr/share/doc/haskell-binary-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-instances-1.0.4-117-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-instances
version:              1.0.4
visibility:           public
id:                   binary-instances-1.0.4-ANNf6Wb25G87iEeW78uRaZ
key:                  binary-instances-1.0.4-ANNf6Wb25G87iEeW78uRaZ
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/haskellari/binary-instances#readme
synopsis:             Orphan instances for binary
description:
    `binary-instances` defines orphan instances for types in some popular packages.

category:             Web
abi:                  34f58ef6418055209e8a2e87447a4371
exposed:              True
exposed-modules:
    Data.Binary.Instances Data.Binary.Instances.Aeson
    Data.Binary.Instances.CaseInsensitive
    Data.Binary.Instances.Hashable Data.Binary.Instances.Primitive
    Data.Binary.Instances.Scientific Data.Binary.Instances.Tagged
    Data.Binary.Instances.Text Data.Binary.Instances.Time
    Data.Binary.Instances.UnorderedContainers
    Data.Binary.Instances.Vector

import-dirs:          /usr/lib/ghc-9.4.8/site-local/binary-instances-1.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/binary-instances-1.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/binary-instances-1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-instances
hs-libraries:         HSbinary-instances-1.0.4-ANNf6Wb25G87iEeW78uRaZ
depends:
    aeson-2.1.2.1-J19dEw13kUOF5hLEOQVj2r base-4.17.2.1 binary-0.8.9.1
    binary-orphans-1.0.5-6zPWKK9kAx9Lpso3QKRPd
    case-insensitive-1.2.1.0-A0C3sKUh8bjBoKTAh9uBrV
    hashable-1.4.4.0-KHdv63hvW7JkoOGsLWKac
    primitive-0.9.1.0-2rF1KRuV9tjItame9gIzcT
    scientific-0.3.8.0-JD5EMEyFBUc5yMNfC55Oq6
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2
    text-binary-0.2.1.1-2Sbl9JTNRDTGn32vfvCeKg
    time-compat-1.9.7-7TzXwWhGnkdERnMe40Z7Y6
    unordered-containers-0.2.20-1i1FNKzvn6TI2R1AzcNrcz
    vector-0.13.2.0-FNdsFzivQrc5gVfjRMxS7n
    vector-binary-instances-0.2.5.2-H1b7sHFbkYrCTzTQ9i4R9x

haddock-interfaces:
    /usr/share/doc/haskell-binary-instances/html/binary-instances.haddock

haddock-html:         /usr/share/doc/haskell-binary-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
